@@ -20,19 +20,13 @@
 
 #include "config.h"
 
-#include <glib.h>
-#include <gnome.h>
-
-#include <stdio.h>
+#include <glib/gi18n.h>
 #include <fcntl.h>
-#include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
 #include <sys/stat.h>
-#include <sys/ioctl.h>
 #include <sys/wait.h>
-#include <linux/major.h>
 #include <string.h>
+#include <stdio.h>
+#include <unistd.h>
 
 #ifdef HAVE_LINUX_FD_H
 #include <linux/fd.h>
@@ -109,7 +103,7 @@ make_mformat_cmd_args (GFloppy *floppy)
 		g_ptr_array_add (args, floppy->volume_name);
 	}
 
-	g_ptr_array_add (args, "-c");
+	g_ptr_array_add (args, "-t");
 	g_ptr_array_add (args, geometry_args[floppy->size][0]);
 
 	g_ptr_array_add (args, "-h");
@@ -143,6 +137,9 @@ make_mkdosfs_cmd_args (GFloppy     *floppy,
 		g_ptr_array_add (args, floppy->volume_name);
 	}
 
+	if (!g_ascii_isdigit (floppy->device[strlen(floppy->device) - 1]))
+		g_ptr_array_add (args, "-I");
+
 	g_ptr_array_add (args, floppy->device);
 	g_ptr_array_add (args, NULL);
 
@@ -342,7 +339,7 @@ execute_fs_creation_cmd (GFloppy           *floppy,
 		if ((type != CMD_MKE2FS || has_real_err_output) &&
 		     strlen (err_output) > 0) {
 			msg = g_strdup_printf (_("The filesystem creation utility (%s) reported the following errors:\n\n%s (%d)"),
-					       (char *)args->pdata[0], err_output, strlen (err_output)); // FIXME:
+					       (char *)args->pdata[0], err_output, (int)(strlen (err_output))); // FIXME:
 			fd_print (floppy, MSG_ERROR, msg);
 			g_free (msg);
 
@@ -579,7 +576,7 @@ test_floppy_device (char *device)
 
 	if (stat (device, &s) < 0)
 		return GFLOPPY_NO_DEVICE;
-	if (!S_ISBLK(s.st_mode) || MAJOR(s.st_rdev) != FLOPPY_MAJOR)
+	if (!S_ISBLK(s.st_mode))
 		return GFLOPPY_NO_DEVICE;
 
 	if (access (device, R_OK|W_OK) != 0)
@@ -599,6 +596,9 @@ test_floppy_device (char *device)
 		} else {
 			retval = GFLOPPY_NO_DEVICE;
 		}
+	} else {
+		/* For usb floppies */
+		retval = GFLOPPY_DEVICE_OK;
 	}
 	close(fd);
 
