@@ -138,12 +138,25 @@ file_key_press_event_cb (GtkWidget * widget,
                          GdkEventKey * event,
                          gpointer data);
 gboolean
+file_motion_notify_cb (GtkWidget *widget,
+                       GdkEventMotion *event,
+                       gpointer user_data);
+gboolean 
+file_leave_notify_cb (GtkWidget *widget,
+                      GdkEventCrossing *event,
+                      gpointer user_data);		       
+gboolean
 not_running_timeout_cb (gpointer data);
 
 void
 disable_quick_search_cb (GtkWidget * dialog,
                          gint response,
                          gpointer data);
+void
+single_click_to_activate_key_changed_cb (GConfClient * client, 
+                                         guint cnxn_id,
+                                         GConfEntry * entry,
+                                         gpointer user_data);
 #ifdef __cplusplus
 }
 #endif
